@@ -148,10 +148,10 @@ if __name__ == '__main__':
 	pass
 else:
 	import os
-	os.system('pip install tensorflow==2.2.0')
+	#os.system('pip install tensorflow==2.2.0')
 	import tensorflow as tf 
 	import numpy as np
-	if tf.__version__ == '2.2.0':
+	if tf.__version__ == '2.4.0':
 		pass
 	else:
 		print("Tensorflow version mismatch. Either pip install tf version as specified in the docs or import the libraries in the beginning.")
